==> kodi-pvr-mythtv_20.6.9+ds.orig.tar.xz: kodi-pvr-mythtv-20.6.9/README.md <==
[![License: GPL-2.0-or-later](https://img.shields.io/badge/License-GPL%20v2+-blue.svg)](LICENSE.md)
[![Build and run tests](https://github.com/janbar/pvr.mythtv/actions/workflows/build.yml/badge.svg?branch=Nexus)](https://github.com/janbar/pvr.mythtv/actions/workflows/build.yml)
[![Build Status](https://jenkins.kodi.tv/view/Addons/job/janbar/job/pvr.mythtv/job/Nexus/badge/icon)](https://jenkins.kodi.tv/blue/organizations/jenkins/janbar%2Fpvr.mythtv/branches/)

# MythTV PVR
MythTV PVR client addon for [Kodi](http://kodi.tv)

## Build instructions
When building the addon you have to use the correct branch depending on which version of Kodi you're building against.
For example, if you're building the `master` branch of Kodi you should checkout the `master` branch of this repository. Also make sure you follow this README from the branch in question.

### Linux

    git clone --branch master --depth=1 https://github.com/xbmc/xbmc.git
    git clone --branch Nexus https://github.com/janbar/pvr.mythtv.git
    cd pvr.mythtv && mkdir build && cd build
    cmake -DADDONS_TO_BUILD=pvr.mythtv -DADDON_SRC_PREFIX=../.. -DCMAKE_BUILD_TYPE=Debug \
    -DCMAKE_INSTALL_PREFIX=../../xbmc/addons -DPACKAGE_ZIP=ON ../../xbmc/cmake/addons
    make

The addon files will be placed in `../../xbmc/kodi-build/addons` so if you build Kodi from source and run it directly
the addon will be available as a system addon.

##### Useful links

* [Kodi's PVR user support](http://forum.kodi.tv/forumdisplay.php?fid=170)
* [Kodi's PVR development support](http://forum.kodi.tv/forumdisplay.php?fid=136)

==> kodi-pvr-mythtv_21.1.11+ds.orig.tar.xz: kodi-pvr-mythtv-21.1.11/README.md <==
[![License: GPL-2.0-or-later](https://img.shields.io/badge/License-GPL%20v2+-blue.svg)](LICENSE.md)
[![Build and run tests](https://github.com/janbar/pvr.mythtv/actions/workflows/build.yml/badge.svg?branch=Omega)](https://github.com/janbar/pvr.mythtv/actions/workflows/build.yml)
[![Build Status](https://jenkins.kodi.tv/view/Addons/job/janbar/job/pvr.mythtv/job/Omega/badge/icon)](https://jenkins.kodi.tv/blue/organizations/jenkins/janbar%2Fpvr.mythtv/branches/)

# MythTV PVR
MythTV PVR client addon for [Kodi](http://kodi.tv)

## Build instructions
When building the addon you have to use the correct branch depending on which version of Kodi you're building against.
For example, if you're building the `master` branch of Kodi you should checkout the `master` branch of this repository. Also make sure you follow this README from the branch in question.

### Linux

    git clone --branch master --depth=1 https://github.com/xbmc/xbmc.git
    git clone --branch Nexus https://github.com/janbar/pvr.mythtv.git
    cd pvr.mythtv && mkdir build && cd build
    cmake -DADDONS_TO_BUILD=pvr.mythtv -DADDON_SRC_PREFIX=../.. -DCMAKE_BUILD_TYPE=Debug \
    -DCMAKE_INSTALL_PREFIX=../../xbmc/addons -DPACKAGE_ZIP=ON ../../xbmc/cmake/addons
    make

The addon files will be placed in `../../xbmc/kodi-build/addons` so if you build Kodi from source and run it directly
the addon will be available as a system addon.

##### Useful links

* [Kodi's PVR user support](http://forum.kodi.tv/forumdisplay.php?fid=170)
* [Kodi's PVR development support](http://forum.kodi.tv/forumdisplay.php?fid=136)
